# tglex

Lexical analysis base for telegram bots

[![Coverage](https://codecov.io/gh/cordalace/tglex/branch/master/graph/badge.svg)](https://codecov.io/gh/cordalace/tglex)
[![pypi](https://img.shields.io/pypi/v/tglex)](https://pypi.python.org/pypi/tglex)
[![Code Smells](https://sonarcloud.io/api/project_badges/measure?project=cordalace_tglex&metric=code_smells)](https://sonarcloud.io/dashboard?id=cordalace_tglex)
[![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=cordalace_tglex&metric=security_rating)](https://sonarcloud.io/dashboard?id=cordalace_tglex)
[![Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=cordalace_tglex&metric=vulnerabilities)](https://sonarcloud.io/dashboard?id=cordalace_tglex)
